@@ -86,7 +86,7 @@ impl ServiceChangeListener for ChangeListener {
                 Change::Remove(endpoint)
             };
 
-            let res = self.rx.send(change).await;
+            let res = self.rx.try_send(change);
             if let Err(error) = res {
                 log::error!("failed to modify service's[{}] endpoint list: {}", service_name, error)
             }
